/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.pdfbox.pdfparser.tokens;

/**
 * A lexical token within a PDF.
 * 
 * @see PDFLexer
 * 
 * @author Maruan Sahyoun (sahyoun at fileaffairs.de)
 * @version $Revision: 1.0 $
 */

public class Token
{

    /**
     * The offset within the PDF input source where the token starts.
     * 
     * The offset includes the delimiters if there are any as part of the token
     * and as such must not be in line with the start of the tokens content.
     */
    private long tokenOffset;

    /**
     * The offset within the pdf input source where the token ends.
     *
     * The offset includes the delimiters if there are any as part of the token
     * and as such must not be in line with the end of the tokens content.
     */
    private long tokenEnd;

    /**
     * The token data.
     */
    private String tokenContent;
    
    /**
     * The token type.
     */
    private TokenTypes tokenType;

    /**
     * Constructs a new Token object given its text and kind.
     * @param tokenType 
     * @param tokenContent 
     * @param tokenOffset 
     * @param tokenEnd 
     */
    public Token(TokenTypes tokenType, String tokenContent, long tokenOffset, long tokenEnd)
    {
        this.tokenType = tokenType;
        this.tokenContent = tokenContent;
        this.tokenOffset = tokenOffset;
        this.tokenEnd = tokenEnd;
        
    }

    /**
     * Gets the offset from where the token starts.
     * 
     * @return the tokens start position.
     */
    public long getOffset()
    {
        return tokenOffset;
    }

    /**
     * Gets the offset where the token ends.
     * 
     * @return the tokens end position.
     */
    public long getEnd()
    {
        return tokenEnd;
    }

    /**
     * Gets the tokens content.
     * 
     * @return the tokens end position.
     */
    public String getContent()
    {
        return tokenContent;
    }

    /**
     * Gets the tokens type.
     * 
     * @see TokenTypes
     * @return the tokens end position.
     */
    public TokenTypes getTokenType()
    {
        return tokenType;
    }
}
