package org.apache.pdfbox.io;

import java.io.IOException;

import org.apache.pdfbox.io.RandomAccessRead;

public class RandomAccessByteArray implements RandomAccessRead
{

    private byte[] byteArray;
    private long currentPosition = 0;
    
    public RandomAccessByteArray(byte[] byteArray)
    {
        if (byteArray == null)
        {
            throw new NullPointerException();
        }
        this.byteArray = byteArray;
    }
    
    @Override
    public void close() throws IOException
    {
        byteArray = null;

    }

    @Override
    public int read() throws IOException
    {
        if (byteArray == null)
        {
            throw new IOException("RandomAccessByteArray already closed");   
        }
        
        if (currentPosition == byteArray.length)
        {
            return -1;
        }

        int dataRead = 0xff & byteArray[(int)currentPosition];
        currentPosition += 1;
        return dataRead;
    }

    @Override
    public int read(byte[] b, int offset, int length) throws IOException
    {
        if (byteArray == null)
        {
            throw new IOException("RandomAccessByteArray already closed");   
        }
        
        if (currentPosition + length == byteArray.length)
        {
            length = (int)(byteArray.length - currentPosition);
        }
        System.arraycopy(byteArray, (int)currentPosition, b, offset, length);
        
        currentPosition += length;
            
        return length; 
    }

    @Override
    public long getPosition() throws IOException
    {
        if (byteArray == null)
        {
            throw new IOException("RandomAccessByteArray already closed");   
        }
        return currentPosition;
    }

    @Override
    public void seek(long position) throws IOException
    {
        if (position > byteArray.length)
        {
            
        } 
        else
        {
            currentPosition = position;
        }
    }

    @Override
    public long length() throws IOException
    {
        return byteArray.length;
    }

}