package org.apache.pdfbox.io;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

public class RandomAccessByteArrayInputStream implements RandomAccessRead
{

    private long currentPosition = 0;
    private InputStream inputStream;
    
    public RandomAccessByteArrayInputStream(ByteArrayInputStream inputStream)
    {
        if (inputStream == null)
        {
            throw new NullPointerException();
        }
        this.inputStream = inputStream;
    }

    public RandomAccessByteArrayInputStream(byte[] byteArray)
    {
        if (byteArray == null)
        {
            throw new NullPointerException();
        }
        this.inputStream = new ByteArrayInputStream(byteArray);
    }
    
    
    
    @Override
    public void close() throws IOException
    {
        inputStream.close();

    }

    @Override
    public int read() throws IOException
    {
        currentPosition +=1;
        return inputStream.read();
    }

    @Override
    public int read(byte[] b, int offset, int length) throws IOException
    {
        currentPosition += length;
        return inputStream.read(b, offset, length); 
    }

    @Override
    public long getPosition() throws IOException
    {
        return currentPosition;
    }

    @Override
    public void seek(long position) throws IOException
    {
        inputStream.reset();
        inputStream.skip(position);
    }

    @Override
    public long length() throws IOException
    {
        return inputStream.available();
    }

}